@@ -23,7 +23,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_osi_pag.c,v 1.21.2.11 2008/01/04 18:40:30 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_osi_pag.c,v 1.29.4.8 2007/01/15 15:51:01 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -145,7 +145,6 @@ getpag(void)
  */
 
 static int afs_pag_sleepcnt = 0;
-static int afs_pag_timewarn = 0;
 
 static int
 afs_pag_sleep(struct AFS_UCRED **acred)
@@ -156,13 +155,6 @@ afs_pag_sleep(struct AFS_UCRED **acred)
 	if(osi_Time() - pag_epoch < pagCounter) {
 	    rv = 1;
 	}
-	if (rv && (osi_Time() < pag_epoch)) {
-	    if (!afs_pag_timewarn) {
-		afs_pag_timewarn = 1;
-		printf("clock went backwards, not PAG throttling");
-	    }
-	    rv = 0;
-	}
     }
 
     return rv;
@@ -429,9 +421,20 @@ AddPag(afs_int32 aval, struct AFS_UCRED **credpp)
 int
 afs_InitReq(register struct vrequest *av, struct AFS_UCRED *acred)
 {
+    int code;
+
     AFS_STATCNT(afs_InitReq);
+    memset(av, 0, sizeof(*av));
     if (afs_shuttingdown)
 	return EIO;
+
+#ifdef AFS_LINUX26_ENV
+#if !defined(AFS_NONFSTRANS)
+    if (osi_linux_nfs_initreq(av, acred, &code))
+	return code;
+#endif
+#endif
+
     av->uid = PagInCred(acred);
     if (av->uid == NOPAG) {
 	/* Afs doesn't use the unix uid for anuthing except a handle
@@ -598,16 +601,15 @@ out:
 #if defined(AFS_LINUX26_ENV) && defined(LINUX_KEYRING_SUPPORT)
     if (pag == NOPAG) {
 	struct key *key;
-	afs_uint32 upag, newpag;
+	afs_uint32 pag, newpag;
 
 	key = request_key(&key_type_afs_pag, "_pag", NULL);
 	if (!IS_ERR(key)) {
 	    if (key_validate(key) == 0 && key->uid == 0) {	/* also verify in the session keyring? */
-		upag = (afs_uint32) key->payload.value;
-		if (((upag >> 24) & 0xff) == 'A') {
-		    __setpag(&cred, upag, &newpag, 0);
-		    pag = (afs_int32) upag;
-		}
+
+		pag = (afs_uint32) key->payload.value;
+		if (((pag >> 24) & 0xff) == 'A')
+		    __setpag(&cred, pag, &newpag, 0);
 	    }
 	    key_put(key);
 	} 
