@@ -60,6 +60,8 @@
 #define SYS_NAME_ID_ppc_darwin_70        507
 #define SYS_NAME_ID_ppc_darwin_80        508
 #define SYS_NAME_ID_x86_darwin_80        509
+#define SYS_NAME_ID_ppc_darwin_90        510
+#define SYS_NAME_ID_x86_darwin_90        511
 
 #define SYS_NAME_ID_next_mach20		 601
 #define SYS_NAME_ID_next_mach30		 602
@@ -97,6 +99,7 @@
 #define SYS_NAME_ID_sun4x_58		 939
 #define SYS_NAME_ID_sun4x_59		 940
 #define SYS_NAME_ID_sun4x_510		 941
+#define SYS_NAME_ID_sun4x_511		 942
 
 /* Sigh. If I leave a gap here IBM will do this sequentially. If I don't
    they won't allocate sunx86 IDs at all. So leave a gap and pray. */
@@ -104,6 +107,7 @@
 #define SYS_NAME_ID_sunx86_58		 951
 #define SYS_NAME_ID_sunx86_59		 952
 #define SYS_NAME_ID_sunx86_510		 953
+#define SYS_NAME_ID_sunx86_511		 954
 
 #define SYS_NAME_ID_vax_ul4		1003
 #define SYS_NAME_ID_vax_ul40		1004
@@ -157,6 +161,7 @@
 #define SYS_NAME_ID_s390_linux2         1900
 #define SYS_NAME_ID_s390_linux22        1901
 #define SYS_NAME_ID_s390_linux24        1902
+#define SYS_NAME_ID_s390_linux26        1907
 #define SYS_NAME_ID_s390x_linux2         1903
 #define SYS_NAME_ID_s390x_linux22        1904
 #define SYS_NAME_ID_s390x_linux24        1905
@@ -178,6 +183,7 @@
 #define SYS_NAME_ID_i386_fbsd_52        2107
 #define SYS_NAME_ID_i386_fbsd_53        2108
 #define SYS_NAME_ID_i386_fbsd_60        2112
+#define SYS_NAME_ID_i386_fbsd_61        2113
 
 #define SYS_NAME_ID_ia64_linux2		2200
 #define SYS_NAME_ID_ia64_linux22	2201
@@ -209,6 +215,20 @@
 #define SYS_NAME_ID_i386_nbsd21		2525
 #define SYS_NAME_ID_i386_nbsd30		2526
 #define SYS_NAME_ID_amd64_nbsd20	2527
+#define SYS_NAME_ID_i386_nbsd40 2528
+#define SYS_NAME_ID_i386_nbsd50 2529
+#define SYS_NAME_ID_sparc64_nbsd30 2530
+#define SYS_NAME_ID_sparc64_nbsd40 2531
+#define SYS_NAME_ID_sparc64_nbsd50 2532
+#define SYS_NAME_ID_amd64_nbsd30 2533
+#define SYS_NAME_ID_amd64_nbsd40 2534
+#define SYS_NAME_ID_amd64_nbsd50 2535
+#define SYS_NAME_ID_alpha_nbsd30 2536
+#define SYS_NAME_ID_alpha_nbsd40 2537
+#define SYS_NAME_ID_alpha_nbsd50 2538
+#define SYS_NAME_ID_macppc_nbsd30 2539
+#define SYS_NAME_ID_macppc_nbsd40 2540
+#define SYS_NAME_ID_macppc_nbsd50 2541
 
 #define SYS_NAME_ID_i386_obsd31		2600
 #define SYS_NAME_ID_i386_obsd32		2601
@@ -218,6 +238,7 @@
 #define SYS_NAME_ID_i386_obsd36		2605
 #define SYS_NAME_ID_i386_obsd37		2606
 #define SYS_NAME_ID_i386_obsd38		2607
+#define SYS_NAME_ID_i386_obsd39		2608
 
 #define SYS_NAME_ID_amd64_linux2        2700
 #define SYS_NAME_ID_amd64_linux22       2701
